@@ -4,8 +4,4 @@
 pub mod shared;
 
 pub use ckb_snapshot::{Snapshot, SnapshotMgr};
-use p2p::SessionId;
 pub use shared::Shared;
-
-/// Alias session id
-pub(crate) type PeerIndex = SessionId;
